Learn R Programming

PheVis (version 1.0.4)

build_qantsur: build_qantsur

Description

build quantile threshold based on icd variables and omega constant

Usage

build_qantsur(df, var.icd, omega)

Value

A numeric vector with the thresholds for the extrema populations.

Arguments

df

the dataframe containing the icd codes.

var.icd

the main icd codes

omega

the constant to define the extrema populations